@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import random
-from collections.abc import Sequence
 from typing import Type
 from typing import TypeVar
 from typing import no_type_check
@@ -211,63 +210,3 @@ class NoteSet(Cached):
 
     def __getnewargs_ex__(self):
         return (self.notes,), {'root': self.root}
-
-
-CHROMATIC_NOTESET = NoteSet(frozenset(config.chromatic_notes))
-
-
-class NoteRange(Sequence[SpecificNote]):
-    def __init__(
-        self,
-        start: SpecificNote | str,
-        stop: SpecificNote | str,
-        noteset: NoteSet = CHROMATIC_NOTESET,
-    ):
-        if isinstance(start, str):
-            start = SpecificNote.from_str(start)
-        if isinstance(stop, str):
-            stop = SpecificNote.from_str(stop)
-
-        """both ends included"""
-        if start > stop:
-            raise ValueError('start should be less than stop')
-
-        if not {start.abstract, stop.abstract} <= noteset.notes:
-            raise KeyError('start and stop notes should be in the noteset')
-
-        self.start = start
-        self.stop = stop
-        self.noteset = noteset
-        self._key = self.start, self.stop, self.noteset
-
-    def _getitem_int(self, item: int) -> SpecificNote:
-        if 0 <= item < len(self):
-            q = self.noteset.add_note(self.start, item)
-            return q
-        elif -len(self) <= item < 0: return self.noteset.add_note(self.stop, item + 1)
-        else: raise IndexError('index out of range')
-
-    @overload
-    def __getitem__(self, i: int) -> SpecificNote: ...
-
-    @overload
-    def __getitem__(self, s: slice) -> NoteRange: ...
-
-    def __getitem__(self, item: int | slice) -> SpecificNote | NoteRange:
-        if isinstance(item, int): return self._getitem_int(item)
-        elif isinstance(item, slice):
-            if not 0 <= item.start <= item.stop <= len(self):
-                raise IndexError('NoteRange slice is out of range')
-            return NoteRange(self._getitem_int(item.start), self._getitem_int(item.stop), self.noteset)
-        else: raise TypeError(f'NoteRange indices must be integers or slices, got {type(item)}')
-
-    def __contains__(self, item: object) -> bool:
-        if not isinstance(item, SpecificNote):
-            return False
-        return item.abstract in self.noteset and self.start <= item <= self.stop
-
-    def __iter__(self): return (self[i] for i in range(len(self)))
-    def __repr__(self): return f'NoteRange({self.start}, {self.stop}, noteset={self.noteset})'
-    def __len__(self): return self.noteset.subtract(self.stop, self.start) + 1
-    def __eq__(self, other): return self._key == other._key
-    def __hash__(self): return hash(self._key)
