@@ -15,42 +15,42 @@ from musictool.util.color import hex_to_rgb
 class Scale(NoteSet):
     intervals_to_name = {
         # diatonic
-        frozenset({2, 4, 5, 7, 9, 11}): 'major',
-        frozenset({2, 3, 5, 7, 9, 10}): 'dorian',
-        frozenset({1, 3, 5, 7, 8, 10}): 'phrygian',
-        frozenset({2, 4, 6, 7, 9, 11}): 'lydian',
-        frozenset({2, 4, 5, 7, 9, 10}): 'mixolydian',
-        frozenset({2, 3, 5, 7, 8, 10}): 'minor',
-        frozenset({1, 3, 5, 6, 8, 10}): 'locrian',
+        frozenset({0, 2, 4, 5, 7, 9, 11}): 'major',
+        frozenset({0, 2, 3, 5, 7, 9, 10}): 'dorian',
+        frozenset({0, 1, 3, 5, 7, 8, 10}): 'phrygian',
+        frozenset({0, 2, 4, 6, 7, 9, 11}): 'lydian',
+        frozenset({0, 2, 4, 5, 7, 9, 10}): 'mixolydian',
+        frozenset({0, 2, 3, 5, 7, 8, 10}): 'minor',
+        frozenset({0, 1, 3, 5, 6, 8, 10}): 'locrian',
         # harmonic
-        frozenset({2, 3, 5, 7, 8, 11}): 'h_minor',
-        frozenset({1, 3, 5, 6, 9, 10}): 'h_locrian',
-        frozenset({2, 4, 5, 8, 9, 11}): 'h_major',
-        frozenset({2, 3, 6, 7, 9, 10}): 'h_dorian',
-        frozenset({1, 4, 5, 7, 8, 10}): 'h_phrygian',
-        frozenset({3, 4, 6, 7, 9, 11}): 'h_lydian',
-        frozenset({1, 3, 4, 6, 8, 9}): 'h_mixolydian',
+        frozenset({0, 2, 3, 5, 7, 8, 11}): 'h_minor',
+        frozenset({0, 1, 3, 5, 6, 9, 10}): 'h_locrian',
+        frozenset({0, 2, 4, 5, 8, 9, 11}): 'h_major',
+        frozenset({0, 2, 3, 6, 7, 9, 10}): 'h_dorian',
+        frozenset({0, 1, 4, 5, 7, 8, 10}): 'h_phrygian',
+        frozenset({0, 3, 4, 6, 7, 9, 11}): 'h_lydian',
+        frozenset({0, 1, 3, 4, 6, 8, 9}): 'h_mixolydian',
         # melodic
-        frozenset({2, 3, 5, 7, 9, 11}): 'm_minor',
-        frozenset({1, 3, 5, 7, 9, 10}): 'm_locrian',
-        frozenset({2, 4, 6, 8, 9, 11}): 'm_major',
-        frozenset({2, 4, 6, 7, 9, 10}): 'm_dorian',
-        frozenset({2, 4, 5, 7, 8, 10}): 'm_phrygian',
-        frozenset({2, 3, 5, 6, 8, 10}): 'm_lydian',
-        frozenset({1, 3, 4, 6, 8, 10}): 'm_mixolydian',
+        frozenset({0, 2, 3, 5, 7, 9, 11}): 'm_minor',
+        frozenset({0, 1, 3, 5, 7, 9, 10}): 'm_locrian',
+        frozenset({0, 2, 4, 6, 8, 9, 11}): 'm_major',
+        frozenset({0, 2, 4, 6, 7, 9, 10}): 'm_dorian',
+        frozenset({0, 2, 4, 5, 7, 8, 10}): 'm_phrygian',
+        frozenset({0, 2, 3, 5, 6, 8, 10}): 'm_lydian',
+        frozenset({0, 1, 3, 4, 6, 8, 10}): 'm_mixolydian',
         # pentatonic
-        frozenset({2, 4, 7, 9}): 'p_major',
-        frozenset({2, 5, 7, 10}): 'p_dorian',
-        frozenset({3, 5, 8, 10}): 'p_phrygian',
-        frozenset({2, 5, 7, 9}): 'p_mixolydian',
-        frozenset({3, 5, 7, 10}): 'p_minor',
+        frozenset({0, 2, 4, 7, 9}): 'p_major',
+        frozenset({0, 2, 5, 7, 10}): 'p_dorian',
+        frozenset({0, 3, 5, 8, 10}): 'p_phrygian',
+        frozenset({0, 2, 5, 7, 9}): 'p_mixolydian',
+        frozenset({0, 3, 5, 7, 10}): 'p_minor',
         # sudu
-        frozenset({2, 4, 5, 7, 9}): 's_major',
-        frozenset({2, 3, 5, 7, 10}): 's_dorian',
-        frozenset({1, 3, 5, 8, 10}): 's_phrygian',
-        frozenset({2, 4, 7, 9, 11}): 's_lydian',
-        frozenset({2, 5, 7, 9, 10}): 's_mixolydian',
-        frozenset({3, 5, 7, 8, 10}): 's_minor',
+        frozenset({0, 2, 4, 5, 7, 9}): 's_major',
+        frozenset({0, 2, 3, 5, 7, 10}): 's_dorian',
+        frozenset({0, 1, 3, 5, 8, 10}): 's_phrygian',
+        frozenset({0, 2, 4, 7, 9, 11}): 's_lydian',
+        frozenset({0, 2, 5, 7, 9, 10}): 's_mixolydian',
+        frozenset({0, 3, 5, 7, 8, 10}): 's_minor',
     }
     name_to_intervals = {v: k for k, v in intervals_to_name.items()}
     root: Note
